@@ -9,10 +9,8 @@ __all__ = ["sin_gen", "cos_gen"]
 def sin_gen(iterable: Iterable[Number], magnitude: Number = 1) -> Iterable[Number]:
     """
 
-    :param func:
-    :type func:
-    :param kw:
-    :type kw:
+    :param magnitude:
+    :type magnitude:
     :param iterable:
     :type iterable:"""
     for a in iterable:
@@ -22,10 +20,8 @@ def sin_gen(iterable: Iterable[Number], magnitude: Number = 1) -> Iterable[Numbe
 def cos_gen(iterable: Iterable, magnitude: Number = 1) -> Iterable[Number]:
     """
 
-    :param func:
-    :type func:
-    :param kw:
-    :type kw:
+    :param magnitude:
+    :type magnitude:
     :param iterable:
     :type iterable:"""
     for a in iterable:
@@ -35,6 +31,7 @@ def cos_gen(iterable: Iterable, magnitude: Number = 1) -> Iterable[Number]:
 if __name__ == "__main__":
 
     def assda():
+        """description"""
         import numpy
 
         for i in cos_gen(numpy.arange(0, 100, 0.1)):
